==> senior_design_system-6.0.0.tar.gz: example/lib/pages/list.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class ListExample extends StatelessWidget {
  const ListExample({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final showSnackbar = () {
      ScaffoldMessenger.of(context).showSnackBar(
        SeniorSnackBar.message(
          message: 'You just tapped a card with quotes',
        ),
      );
    };

    return PageWrapper(
      title: 'List',
      child: SingleChildScrollView(
        child: Column(
          children: [
            Panel(
              title: 'No separator line',
              child: SeniorList(
                items: [
                  SeniorListItem(
                    type: ItemType.emphasisBold,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.emphasisBold,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutralBold,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.neutralColor800,
                    title: 'item title',
                    subtitle: 'Item subtitle with more information',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutralBold,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.neutralColor800,
                    title: 'item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                ],
              ),
            ),
            Panel(
              title: 'With separator line',
              child: SeniorList(
                withLineSeparator: true,
                items: [
                  SeniorListItem(
                    type: ItemType.emphasis,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.emphasis,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutral,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutral,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                ],
              ),
            ),
            Panel(
              title: 'No title',
              child: SeniorList(
                items: [
                  SeniorListItem(
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                ],
              ),
            ),
            Panel(
              title: 'Title only',
              child: SeniorList(
                items: [
                  SeniorListItem(
                    type: ItemType.emphasis,
                    title: 'Item title',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutral,
                    title: 'Item title',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.emphasis,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutral,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.emphasisBold,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutralBold,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}

==> senior_design_system-7.0.4.tar.gz: example/lib/pages/list.example.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/page_wrapper.dart';
import '../widgets/panel.dart';

class ListExample extends StatelessWidget {
  const ListExample({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final showSnackbar = () {
      ScaffoldMessenger.of(context).showSnackBar(
        SeniorSnackBar.message(
          message: 'You just tapped a card with quotes',
        ),
      );
    };

    return PageWrapper(
      title: 'List',
      child: SingleChildScrollView(
        child: Column(
          children: [
            Panel(
              title: 'No separator line',
              child: SeniorList(
                items: [
                  SeniorListItem(
                    type: ItemType.emphasisBold,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.emphasisBold,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutralBold,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.grayscale80,
                    title: 'item title',
                    subtitle: 'Item subtitle with more information',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutralBold,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.grayscale80,
                    title: 'item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                ],
              ),
            ),
            Panel(
              title: 'With separator line',
              child: SeniorList(
                withLineSeparator: true,
                items: [
                  SeniorListItem(
                    type: ItemType.emphasis,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.emphasis,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutral,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutral,
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                ],
              ),
            ),
            Panel(
              title: 'No title',
              child: SeniorList(
                items: [
                  SeniorListItem(
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    icon: FontAwesomeIcons.phone,
                    iconColor: SeniorColors.pureWhite,
                    iconBackground: SeniorColors.primaryColor500,
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                ],
              ),
            ),
            Panel(
              title: 'Title only',
              child: SeniorList(
                items: [
                  SeniorListItem(
                    type: ItemType.emphasis,
                    title: 'Item title',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutral,
                    title: 'Item title',
                    rightIcon: FontAwesomeIcons.chevronRight,
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.emphasis,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutral,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.emphasisBold,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                  SeniorListItem(
                    type: ItemType.neutralBold,
                    title: 'Item title',
                    subtitle: 'Item subtitle with more information',
                    rightLabel: '123',
                    onTap: showSnackbar,
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}
